==> auto-ui-2.4.55.tgz: package/es/action-sheet/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import { createPortal } from 'react-dom';
import Modal from '../modal/index';
import './style/index.scss';
var ActionSheet = /** @class */ (function (_super) {
    __extends(ActionSheet, _super);
    function ActionSheet(props) {
        var _this = _super.call(this, props) || this;
        _this.div = null;
        _this.onItemClick = function (value) {
            return function () {
                if (_this.props.onClick) {
                    _this.props.onClick(value);
                }
            };
        };
        _this.renderTitle = function () {
            var title = _this.props.title;
            if (title) {
                if (typeof title === 'string' || typeof title === 'number') {
                    return React.createElement("h1", { className: "x-actionsheet__title" }, title);
                }
                return React.createElement("header", { className: "x-actionsheet__title" }, title);
            }
            return null;
        };
        _this.renderItem = function (children, value, className) {
            if (typeof children === 'string' || typeof children === 'number') {
                var composeClassName_1 = cn('x-actionsheet__button', className);
                return (React.createElement("button", { className: composeClassName_1, onClick: _this.onItemClick(value) }, children));
            }
            var composeClassName = cn('x-actionsheet__item-con', className);
            return (React.createElement("div", { className: composeClassName, onClick: _this.onItemClick(value) }, children));
        };
        _this.div = document.createElement('div');
        _this.div.classList.add('_x_actionsheet_');
        document.body.appendChild(_this.div);
        return _this;
    }
    ActionSheet.prototype.componentWillUnmount = function () {
        if (this.div) {
            document.body.removeChild(this.div);
        }
    };
    ActionSheet.prototype.render = function () {
        if (this.div) {
            return createPortal(this.content(), this.div);
        }
        return null;
    };
    ActionSheet.prototype.content = function () {
        var _this = this;
        var _a = this.props, title = _a.title, visible = _a.visible, className = _a.className, onClose = _a.onClose, onClick = _a.onClick, items = _a.items, closeText = _a.closeText, otherProps = __rest(_a, ["title", "visible", "className", "onClose", "onClick", "items", "closeText"]);
        if (!Array.isArray(items)) {
            throw new TypeError('ActionSheet 的 items 必须是个数组');
        }
        var composeClassName = cn('x-actionsheet', className);
        return (React.createElement(Modal, __assign({ visible: visible, onMaskClick: onClose, className: composeClassName }, otherProps),
            this.renderTitle(),
            React.createElement("div", { className: "x-actionsheet__list" }, items.map(function (item, index) {
                var name = item.name, value = item.value, className = item.className;
                return (React.createElement("div", { className: "x-actionsheet__item", key: index }, _this.renderItem(name, value, className)));
            })),
            !!closeText && (React.createElement("button", { className: "x-actionsheet__closebtn", onClick: onClose }, closeText))));
    };
    return ActionSheet;
}(React.PureComponent));
export default ActionSheet;

==> auto-ui-2.4.63.tgz: package/es/action-sheet/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import { createPortal } from 'react-dom';
import Modal from '../modal/index';
import './style/index.scss';
var ActionSheet = /** @class */ (function (_super) {
    __extends(ActionSheet, _super);
    function ActionSheet(props) {
        var _this = _super.call(this, props) || this;
        _this.div = null;
        _this.onItemClick = function (value) {
            return function () {
                if (_this.props.onClick) {
                    _this.props.onClick(value);
                }
            };
        };
        _this.renderTitle = function () {
            var title = _this.props.title;
            if (title) {
                if (typeof title === 'string' || typeof title === 'number') {
                    return React.createElement("h1", { className: "x-actionsheet__title" }, title);
                }
                return React.createElement("header", { className: "x-actionsheet__title" }, title);
            }
            return null;
        };
        _this.renderItem = function (children, value, className) {
            if (typeof children === 'string' || typeof children === 'number') {
                var composeClassName_1 = cn('x-actionsheet__button', className);
                return (React.createElement("button", { className: composeClassName_1, onClick: _this.onItemClick(value) }, children));
            }
            var composeClassName = cn('x-actionsheet__item-con', className);
            return (React.createElement("div", { className: composeClassName, onClick: _this.onItemClick(value) }, children));
        };
        _this.div = document.createElement('div');
        _this.div.classList.add('_x_actionsheet_');
        document.body.appendChild(_this.div);
        return _this;
    }
    ActionSheet.prototype.componentWillUnmount = function () {
        if (this.div) {
            document.body.removeChild(this.div);
        }
    };
    ActionSheet.prototype.render = function () {
        if (this.div) {
            return createPortal(this.content(), this.div);
        }
        return null;
    };
    ActionSheet.prototype.content = function () {
        var _this = this;
        var _a = this.props, title = _a.title, visible = _a.visible, className = _a.className, onClose = _a.onClose, onClick = _a.onClick, items = _a.items, closeText = _a.closeText, otherProps = __rest(_a, ["title", "visible", "className", "onClose", "onClick", "items", "closeText"]);
        if (!Array.isArray(items)) {
            throw new TypeError('ActionSheet 的 items 必须是个数组');
        }
        var composeClassName = cn('x-actionsheet', className);
        return (React.createElement(Modal, __assign({ visible: visible, onMaskClick: onClose, className: composeClassName }, otherProps),
            this.renderTitle(),
            React.createElement("div", { className: "x-actionsheet__list" }, items.map(function (item, index) {
                var name = item.name, value = item.value, className = item.className;
                return (React.createElement("div", { className: "x-actionsheet__item", key: index }, _this.renderItem(name, value, className)));
            })),
            !!closeText && (React.createElement("button", { className: "x-actionsheet__closebtn", onClick: onClose }, closeText))));
    };
    return ActionSheet;
}(React.PureComponent));
export default ActionSheet;
